@@ -212,8 +212,6 @@ static exceptionDef *exception_list_attr(sipSpec *pt, PyObject *obj,
 static valueDef *expr(sipSpec *pt, PyObject *obj, const char *encoding);
 static valueDef *expr_attr(sipSpec *pt, PyObject *obj, const char *name,
         const char *encoding);
-static void extract_list_attr(sipSpec *pt, PyObject *obj, const char *name,
-        const char *encoding);
 static fcallDef *functioncall(sipSpec *pt, PyObject *obj,
         const char *encoding);
 static ifaceFileDef *ifacefile(sipSpec *pt, PyObject *obj,
@@ -366,8 +364,6 @@ sipSpec *py2c(PyObject *spec, const char *encoding)
     pt->nrvirthandlers = int_attr(spec, "nr_virtual_handlers");
     pt->qobject_cd = class_attr(pt, spec, "pyqt_qobject", encoding);
 
-    extract_list_attr(pt, spec, "extracts", encoding);
-
     return pt;
 }
 
@@ -1229,37 +1225,6 @@ static exceptionDef *exception_list_attr(sipSpec *pt, PyObject *obj,
 }
 
 
-/*
- * Convert a Extract list attribute.
- */
-static void extract_list_attr(sipSpec *pt, PyObject *obj, const char *name,
-        const char *encoding)
-{
-    PyObject *attr = PyObject_GetAttrString(obj, name);
-    Py_ssize_t i;
-
-    assert(attr != NULL);
-
-    for (i = 0; i < PyList_Size(attr); ++i)
-    {
-        PyObject *item;
-        const char *id;
-        int order;
-        codeBlock *part;
-
-        item = PyList_GetItem(attr, i);
-
-        id = str_attr(item, "id", encoding);
-        order = int_attr(item, "order");
-        part = codeblock_attr(item, "part", encoding);
-
-        addExtractPart(pt, id, order, part);
-    }
-
-    Py_DECREF(attr);
-}
-
-
 /*
  * Convert a FunctionCall object.
  */
@@ -1650,7 +1615,6 @@ static memberDef *member_list_attr(sipSpec *pt, PyObject *obj,
 static moduleDef *module(sipSpec *pt, PyObject *obj, const char *encoding)
 {
     moduleDef *value;
-    char *basename;
     PyObject *needed_types_obj;
     Py_ssize_t nr_needed_types;
 
@@ -1665,12 +1629,7 @@ static moduleDef *module(sipSpec *pt, PyObject *obj, const char *encoding)
     cache(&cache_module, obj, value);
 
     value->fullname = cachedname_attr(obj, "fq_py_name", encoding);
-
-    if ((basename = strrchr(value->fullname->text, '.')) == NULL)
-        value->name = value->fullname->text;
-    else
-        value->name = basename + 1;
-
+    value->name = str_attr(obj, "py_name", encoding);
     value->docstring = docstring_attr(obj, "docstring", encoding);
 
     if (bool_attr(obj, "call_super_init"))
@@ -2392,7 +2351,6 @@ static throwArgs *throw_arguments(sipSpec *pt, PyObject *obj,
 {
     throwArgs *value;
     PyObject *args_obj;
-    Py_ssize_t i;
 
     if (obj == Py_None)
         return NULL;
@@ -2402,10 +2360,19 @@ static throwArgs *throw_arguments(sipSpec *pt, PyObject *obj,
     args_obj = PyObject_GetAttrString(obj, "arguments");
     assert(args_obj != NULL);
 
-    for (i = 0; i < PyList_Size(args_obj) && i < MAX_NR_ARGS; ++i)
-        value->args[i] = exception(pt, PyList_GetItem(args_obj, i), encoding);
+    if (args_obj != Py_None)
+    {
+        Py_ssize_t i;
 
-    value->nrArgs = i;
+        for (i = 0; i < PyList_Size(args_obj) && i < MAX_NR_ARGS; ++i)
+            value->args[i] = exception(pt, PyList_GetItem(args_obj, i), encoding);
+
+        value->nrArgs = i;
+    }
+    else
+    {
+        value->nrArgs = -1;
+    }
 
     Py_DECREF(args_obj);
 
